Text module {#tutorial_table_of_content_text}
=====================

-   @subpage tutorial_install_tesseract

    *Compatibility:* \> OpenCV 3.4

    *Author:* Laurent Berger

    Instructions in order to properly setup tesseract on windows for the text module.
